## 0.0.16

This new version includes an update to the pyproject.toml file and a version bump from 0.0.15 to 0.0.16.

### New Features

- No new features were added in this version.

### Bug Fixes

- No bug fixes were made in this version.

### Updates

- The pyproject.toml file was updated (3773a5) (Eric Ma)
- The version was bumped from 0.0.15 to 0.0.16 (b55951) (Eric Ma)

### Deprecations

- No deprecations were made in this version.
